# PyMathTools
 A really simple Python library to do some math operations <br>
 PyPi page: https://pypi.org/project/pymathtools/
 # Installation
 To install the library, run the following command:
 ```
pip install pymathtools
```
To import it in a script, add the following line:
```
from pymathtools import *
```
# Commands
This package includes the following commands/functions: <br>
__isprime(primenum)__ <br>
Checks if a number is prime. Takes in a integer and returns a bool True/False
```
prime = isprime(17) # Using 17 as an example
print(prime)
```
Response:
```
True
```
__rectanglearea(area1, area2)__
```
rectanglearea = rectanglearea(7, 4)
print(rectanglearea)
```
Response:
```
28
```
__trianglearea(area1, area2)__
```
trianglearea = trianglearea(6, 3)
print(trianglearea)
```
Response:
```
9.0
```
__squarearea(area1)__
```
squarearea = squarearea(7)
print(squarearea)
```
Response:
```
49
```
__cubevolume(length, width, height)__
```
cubevolume = cubevolume(3, 4, 7)
print(cubevolume)
```
Response:
```
49
```
__triangleperimeter(side1, side2, side3)__
```
triangle = triangleperimeter(3, 4, 10)
print(triangle)
```
Response:
```
17
```
__squareperimeter(side1)__
```
square = squareperimeter(410)
print(square)
```
Response:
```
1640
```
__parallelogramperimeter(side1, side2)__
```
parallelogram = parallelogramperimeter(10, 410)
print(parallelogram)
```
Response:
```
840
```
__circlediameter(radius)__
```
circlediam = circlediameter(14)
print(circle)
```
Response:
```
28
```
__circlearea(radius)__
```
circlearea = circlearea(17)
print(circlearea)
```
Response:
```
907.46
```
__mathmean(sum, number)__
```
mathmean = mathmean(sum, number)
